summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorzeertzjq <zeertzjq@outlook.com>2024-08-16 21:11:31 +0200
committerChristian Brabandt <cb@256bit.org>2024-08-16 21:11:31 +0200
commitbc11f6d9d4f580179d3963f3c489881904d6cd62 (patch)
tree6c76466d5c65a5a62e2a6f09ee080c5c388cd075
parent6908db475603c0f37aaf4c3ba13dfdbebd340003 (diff)
patch 9.1.0679: Rename from w_closing to w_locked is incompletev9.1.0679
Problem: Rename from w_closing to w_locked is incomplete (after 9.1.0678). Solution: Rename remaining occurrences of w_closing to w_locked and update comments (zeertzjq). closes: #15504 Signed-off-by: zeertzjq <zeertzjq@outlook.com> Signed-off-by: Christian Brabandt <cb@256bit.org>
-rw-r--r--src/ex_cmds.c2
-rw-r--r--src/structs.h3
-rw-r--r--src/terminal.c8
-rw-r--r--src/version.c2
4 files changed, 8 insertions, 7 deletions
diff --git a/src/structs.h b/src/structs.h
index abda3a0c38..847972f5a8 100644
--- a/src/structs.h
+++ b/src/structs.h
@@ -3785,8 +3785,7 @@ struct window_S
synblock_T *w_s; // for :ownsyntax
#endif
- int w_locked; // window is being closed, don't let
- // autocommands close it too.
+ int w_locked; // don't let autocommands close the window
frame_T *w_frame; // frame containing this window
diff --git a/src/terminal.c b/src/terminal.c
index f80196096d..073f8dd48d 100644
--- a/src/terminal.c
+++ b/src/terminal.c
@@ -3647,7 +3647,7 @@ term_after_channel_closed(term_T *term)
if (term->tl_finish == TL_FINISH_CLOSE)
{
aco_save_T aco;
- int do_set_w_closing = term->tl_buffer->b_nwindows == 0;
+ int do_set_w_locked = term->tl_buffer->b_nwindows == 0;
#ifdef FEAT_PROP_POPUP
win_T *pwin = NULL;
@@ -3678,11 +3678,11 @@ term_after_channel_closed(term_T *term)
{
// Avoid closing the window if we temporarily use it.
if (is_aucmd_win(curwin))
- do_set_w_closing = TRUE;
- if (do_set_w_closing)
+ do_set_w_locked = TRUE;
+ if (do_set_w_locked)
curwin->w_locked = TRUE;
do_bufdel(DOBUF_WIPE, (char_u *)"", 1, fnum, fnum, FALSE);
- if (do_set_w_closing)
+ if (do_set_w_locked)
curwin->w_locked = FALSE;
aucmd_restbuf(&aco);
}
diff --git a/src/version.c b/src/version.c
index 08b3fafd7b..798e558457 100644
--- a/src/version.c
+++ b/src/version.c
@@ -705,6 +705,8 @@ static char *(features[]) =
static int included_patches[] =
{ /* Add new patch number below this line */
/**/
+ 679,
+/**/
678,
/**/
677,
diff --git a/src/ex_cmds.c b/src/ex_cmds.c
index 349269a2bb..b2aaf1cab9 100644
--- a/src/ex_cmds.c
+++ b/src/ex_cmds.c
@@ -2838,7 +2838,7 @@ do_ecmd(
int did_decrement;
buf_T *was_curbuf = curbuf;
// Set the w_closing flag to avoid that autocommands close the
// window. And set b_locked for the same reason.
the_curwin->w_locked = TRUE;
++buf->b_locked;
@@ -2838,7 +2838,7 @@ do_ecmd(
int did_decrement;
buf_T *was_curbuf = curbuf;
- // Set the w_closing flag to avoid that autocommands close the
+ // Set the w_locked flag to avoid that autocommands close the
// window. And set b_locked for the same reason.
the_curwin->w_locked = TRUE;